import React from "react";
import { EchartsInitopts } from "./hooks";
import { EChartsOption, EChartsType } from "echarts";
import { TipsProps } from "./Tips";
export { default as worldJson } from "./assets/mapData/world.json";
export type EventQuery = Parameters<EChartsType["on"]>[1];
export type EventHandler = (params: any, instance: EChartsType) => void;
export type EnlargeEventQuery = Parameters<EChartsType["convertFromPixel"]>[0];
export type EnlargeEventHandler = (
/** 点击区域位置, [x轴,y轴] */
gridIndex: number[], instance: EChartsType, event?: any) => void;
interface EventName {
    eventName: string;
}
export interface Event extends EventName {
    /** 扩大点击区域 */
    enlarge?: false;
    query?: EventQuery;
    handler: EventHandler;
}
export interface EnlargeEvent extends EventName {
    /** 扩大点击区域 */
    enlarge?: true;
    query?: EnlargeEventQuery;
    handler: EnlargeEventHandler;
}
export type EventTypes = Event | EnlargeEvent;
export interface MapData {
    name: string;
    loadFunc: () => Promise<any> | any;
}
export type ThemeKey = "dark" | "light" | "default" | string;
export interface ChartProps {
    /** 是否加载中 */
    loading?: boolean;
    /** 图表配置 */
    option: EChartsOption;
    /** 主题名称 */
    theme?: ThemeKey;
    /** 事件数组 */
    events?: EventTypes[];
    /** resize间隔时间  */
    resizeTime?: number;
    /** 图表初始化配置 */
    initOpts?: EchartsInitopts;
    /** 地图数据 */
    mapData?: MapData;
}
export interface ExChartProps extends ChartProps {
    /** 提示信息 */
    tips?: TipsProps;
    style?: React.CSSProperties;
}
export interface EchartRef {
    getInstance(): EChartsType | undefined;
}
export declare const ExChart: React.MemoExoticComponent<React.ForwardRefExoticComponent<ExChartProps & React.RefAttributes<EchartRef>>>;
export default ExChart;
